# PyEnergyX

PyEnergyX is a simple Python library for energy conversion. 

## Installation

You can install the library directly from the GitHub repository using pip:

```bash
pip install git+https://github.com/mariodgr/pyenergyx.git
